@@ -13,7 +13,6 @@ from talos.thrift.consumer.ttypes import UnlockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionResponse
 from talos.client.TalosClientFactory import ConsumerClient
-from talos.thrift.common.ttypes import GalaxyTalosException
 from talos.utils import Utils
 from talos.utils.Utils import synchronized
 import logging
@@ -74,19 +73,18 @@ class PartitionFetcher(object):
     partitionId = int
     workerId = str
     consumerClient = ConsumerClient
+    commitOffsetClient = ConsumerClient
     curState = int
     topicAndPartition = TopicAndPartition
     topicName = str
     simpleConsumer = SimpleConsumer
     messageReader = MessageReader
 
-    def __init__(self, consumerGroup=None, topicName=None,
-                 topicTalosResourceName=None, partitionId=None,
-                 talosConsumerConfig=None, workerId=None,
-                 consumerClient=None, messageClient=None,
-                 queryPartitionCleint=None, messageProcessor=None,
-                 messageReader=None, simpleConsumer=None,
-                 outerCheckPoint=None):
+    def __init__(self, consumerGroup=None, topicName=None, topicTalosResourceName=None,
+                 partitionId=None, talosConsumerConfig=None, workerId=None,
+                 consumerClient=None, messageClient=None, getPartitionOffsetClient=None,
+                 queryPartitionCleint=None, commitOffsetClient=None, messageProcessor=None,
+                 messageReader=None, simpleConsumer=None, outerCheckPoint=None):
         self.synchronizedLock = threading.Lock()
         self.consumerGroup = consumerGroup
         self.topicTalosResourceName = topicTalosResourceName
@@ -105,7 +103,9 @@ class PartitionFetcher(object):
             self.simpleConsumer = SimpleConsumer(talosConsumerConfig,
                                                  topicAndPartition=self.topicAndPartition,
                                                  messageClient=messageClient)
+        self.getPartitionOffsetClient = getPartitionOffsetClient
         self.queryPartitionClient = queryPartitionCleint
+        self.commitOffsetClient = commitOffsetClient
 
         self.fetcherStateMachine = threading.Thread
 
@@ -117,9 +117,11 @@ class PartitionFetcher(object):
             self.messageReader.set_topic_and_partition(self.topicAndPartition)
             self.messageReader.set_simple_consumer(self.simpleConsumer)
             self.messageReader.set_message_processor(messageProcessor)
-            self.messageReader.set_consumer_client(self.consumerClient)
-            self.messageReader.set_message_client(self.queryPartitionClient)
+            self.messageReader.set_message_client(self.getPartitionOffsetClient)
+            self.messageReader.set_consumer_client(self.commitOffsetClient)
+            self.messageReader.set_query_offset_client(self.queryPartitionClient)
             self.messageReader.set_outer_checkpoint(outerCheckPoint)
+            self.messageReader.init_consumer_metrics()
 
         self.logger.info("The PartitionFetcher for topic: " +
                          str(topicTalosResourceName.topicTalosResourceName)
@@ -138,8 +140,6 @@ class PartitionFetcher(object):
         try:
             self.messageReader.init_start_offset()
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " query partition offset " +
                               "error: we will skip this partition" + str(traceback.format_exc()))
             self.clean()
@@ -248,8 +248,6 @@ class PartitionFetcher(object):
         try:
             self.consumerClient.unlock_partition(unlockRequest)
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
             self.logger.warn("Worker: " + self.workerId + " release partition error: "
                              + str(traceback.format_exc()))
             return
@@ -273,8 +271,6 @@ class PartitionFetcher(object):
         try:
             lockResponse = self.consumerClient.lock_partition(lockRequest)
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " steal partition id : "
                               + str(self.partitionId) + " error! " + str(traceback.format_exc()))
             return False
@@ -296,6 +292,9 @@ class PartitionFetcher(object):
         self.release_partition()
         self.update_state(TASK_STATE.UNLOCKED)
 
+    def get_falcon_data(self):
+        return self.messageReader.get_consumer_metrics().to_json_data()
+
     def shutdown(self):
         # set UNLOCKING to stop read and wait fetcher gracefully quit
         self.update_state(TASK_STATE.UNLOCKING)
